% Quokka3 settingsfile for a PERC cell of Trina Solar with a shingle layout
% calibrated to (non-shingle) production-line cells during ramp-up
% published at Silicon PV 2018: Detailed 3D Full-Cell Modeling in Quokka3: Quantifying Edge and Solder-Pad Losses in an Industrial PERC Cell
% and JPV 2018: A Detailed Full-Cell Model of a 2018 Commercial PERC Solar Cell in Quokka3
% Andreas Fell + Pietro Altermatt

% this shingle settingsfile is simplified to line rear contacts instead of dashes for a smaller numerical mesh
% it is also simplified by using the equivalent-circuit bulk model type to speed-up the simulation largely
% edge recombination is only applied to the long edges (north and south)
% only J02,edge recombination is defined, not recombination at the quasi-neutral bulk edges (Seff,edge)
% this is because the latter is not supported by the equivalent-circtuit bulk model type, however results with J02,edge only are similar to considering both J02,edge and Seff,edge

% (c) 2023 Andreas Fell


Syntax = 'front and rear contact full cell';

FullCellDomainType = 'multi-domain';
CellThickness = 170;
CellSizeX = 156 mm;
CellSizeY = 22 mm;
FrontEdgeDistanceX = 500 um;
FrontEdgeDistanceY = 500 um; % for shingle, this is only applicable to the non-busbar edge
RearEdgeDistanceX = 500 um;
RearEdgeDistanceY = 500 um; % for shingle, this is only applicable to the non-busbar edge
RedundantLineEnable = 1;
CellOverlap = 2 mm;

FrontContactShape = 'line';
FrontMetalShape = 'shingle';
FrontContactNumber = 101;
FrontFingerWidth = 60;
FrontFingerShadingFraction = 0.8;
FrontContactWidth = 60;
FrontContact.OhmicResistivity = 2.7e-3; 

RearContactShape = 'line';
RearMetalShape = 'full';
RearContact.OhmicResistivity = 3e-3;
RearContactNumber = 201;
RearContactWidth = 60;

% busbar settings
EdgeDistanceBusbar = 500 um; % distance between edge and (the edge of) the busbar
FrontBusbarWidth = 800 um; 
RearBusbarWidth = 1100 um; % width of rear Ag pads, half of actual 2.2mm thickness, as the striped pads only cover ~50% of the cell length
FrontBusbarContactEnable = 1;
FrontBusbarContact.OhmicResistivity = 2.7e-3; 
RearBusbarContactEnable = 0;
FrontMetalRsheet = 0.003; % Rsheet = finger line resistance [Ohm/cm] * finger width
RearMetalRsheet = 0.0175;

FrontMetalPolarity = 'n-type';
RearMetalPolarity = 'p-type';

Solver.SolutionType = 'light JV-curve';
Solver.JVCurve.VtermStepSize = 'standard';
Solver.Electrical.MetalModelType = 'finite-differences';
Solver.Electrical.SkinJ0nieff.Type = 'user-T';
Solver.Electrical.SkinJ0nieff.T = 298.15;
Solver.Electrical.BulkModelType = 'equivalent-circuit';

Optical.GenerationModelType = 'Text-Z';
Optical.FrontIllumination.Enable = 1;
Optical.FrontIllumination.Spectrum.Type = 'AM1.5g';
Optical.FrontIllumination.Scale = 1;
Optical.RearIllumination.Enable = 0;
Optical.TextZ.FrontText.Type = 'Text';
Optical.TextZ.FrontText.Text.Type = 'file';
Optical.TextZ.FrontText.Text.File = 'Trina_PERC_Text.csv';
Optical.TextZ.FrontText.FacetAngle = 54;
Optical.TextZ.FrontZ.Type = 'local'; % calculates Z locally from internal optical properties of the skins
Optical.ScaleGeneration = 1;

Thermal.T = 298.15;

Bulk.BackgroundDoping.SettingType = 'dopingtype-resistivity';
Bulk.BackgroundDoping.DopingType = 'p-type';
Bulk.BackgroundDoping.Resistivity = 1.5;
Bulk.Electrical.Recombination.Type = 'intrinsic plus SRH';
Bulk.Electrical.Recombination.SRH(1).Type = 'tau-Et';
Bulk.Electrical.Recombination.SRH(1).taun = 150;
Bulk.Electrical.Recombination.SRH(1).taup = 750;
Bulk.Electrical.Recombination.SRH(1).Et_Ei = 0;


FullFrontSkin.ElectricalModelType = 'lumped';
FullFrontSkin.Lumped.Electrical.RsheetEnable = 1;
FullFrontSkin.Lumped.Electrical.Rsheet = 148.8;
FullFrontSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
FullFrontSkin.Lumped.Electrical.NonContactedRecombination.J0 = 30.7e-15;
FullFrontSkin.Lumped.Electrical.SouthEdgeJ02 = 19e-9; % A/cm
FullFrontSkin.Lumped.Electrical.NorthEdgeJ02 = 19e-9;
FullFrontSkin.OpticalModelType = 'lumped';
FullFrontSkin.Lumped.Optical.Internal.Rint = 0.92;
FullFrontSkin.Lumped.Optical.Internal.Diffuse = 1;

LocalFrontSkin.Enable = 1;
LocalFrontSkin.Width = 300;
LocalFrontSkin.ElectricalModelType = 'lumped';
LocalFrontSkin.Geometry.DepthType = 'user';
LocalFrontSkin.Geometry.DepthUser = 0.66;
LocalFrontSkin.Lumped.Electrical.RsheetEnable = 1;
LocalFrontSkin.Lumped.Electrical.Rsheet = 58.5;
LocalFrontSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
LocalFrontSkin.Lumped.Electrical.ContactedRecombination.J0 = 500e-15;
LocalFrontSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
LocalFrontSkin.Lumped.Electrical.NonContactedRecombination.J0 = 120e-15;
LocalFrontSkin.Lumped.Electrical.EtaColl = 0.882; % depth and collection efficiency from detailed modeling @400nm
LocalFrontSkin.OpticalModelType = 'lumped';
LocalFrontSkin.Lumped.Optical.Internal.Rint = 0.9;
LocalFrontSkin.Lumped.Optical.Internal.Diffuse = 1;

LocalFrontContactSkin.Enable = 1;
LocalFrontContactSkin.ElectricalModelType = 'lumped';
LocalFrontContactSkin.Lumped.Electrical.RsheetEnable = 1;
LocalFrontContactSkin.Lumped.Electrical.Rsheet = 60;
LocalFrontContactSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
LocalFrontContactSkin.Lumped.Electrical.ContactedRecombination.J0 = 500e-15;
% for lack of other data using passivated internal optical properties
LocalFrontContactSkin.OpticalModelType = 'lumped';
LocalFrontContactSkin.Lumped.Optical.Internal.Rint = 0.85;
LocalFrontContactSkin.Lumped.Optical.Internal.Diffuse = 1;

FullRearSkin.ElectricalModelType = 'lumped';
FullRearSkin.Lumped.Electrical.RsheetEnable = 1;
FullRearSkin.Lumped.Electrical.Rsheet = 1e5; % Rsheet must be enabled for all skins for the equivalent-circuit bulk model type; setting high value effectively disables lateral conduction
FullRearSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'Seff';
FullRearSkin.Lumped.Electrical.NonContactedRecombination.Seff = 10;
% internal optics from fit to raytracing results
FullRearSkin.OpticalModelType = 'lumped';
FullRearSkin.Lumped.Optical.Internal.Rint = 0.98;
FullRearSkin.Lumped.Optical.Internal.Diffuse = 1;

LocalRearContactSkin.Enable = 1;
LocalRearContactSkin.ElectricalModelType = 'lumped';
LocalRearContactSkin.Lumped.Electrical.RsheetEnable = 1;
LocalRearContactSkin.Lumped.Electrical.Rsheet = 60;
LocalRearContactSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
LocalRearContactSkin.Lumped.Electrical.ContactedRecombination.J0 = 400e-15;
% internal optics from fit to raytracing results
LocalRearContactSkin.OpticalModelType = 'lumped';
LocalRearContactSkin.Lumped.Optical.Internal.Rint = 0.89;
LocalRearContactSkin.Lumped.Optical.Internal.Diffuse = 1;