% Quokka3 settingsfile for a full-size PERC cell of Trina Solar
% calibrated to production-line cells during ramp-up
% published at Silicon PV 2018: Detailed 3D Full-Cell Modeling in Quokka3: Quantifying Edge and Solder-Pad Losses in an Industrial PERC Cell
% and JPV 2018: A Detailed Full-Cell Model of a 2018 Commercial PERC Solar Cell in Quokka3
% Andreas Fell + Pietro Altermatt
% (c) 2021 Andreas Fell

% uses the multi-domain appraoch to enable full-size simulation of a dashed rear-contact geometry
% simplifies the original examples by
% i) assuming line-shaped instead of dashed contacts at the rear with the same area fraction, resulting in same width as the front lines
% ii) neglects rear Ag pad details


Syntax = 'front and rear contact full cell';

FullCellDomainType = 'multi-domain';
CellThickness = 170;
CellSizeX = 15.6 cm;
CellSizeY = 15.6 cm;
FrontEdgeDistanceX = 500;
RearEdgeDistanceX = 500;
FrontEdgeDistanceY = 500;
RearEdgeDistanceY = 500;
RedundantLineEnable = 1;

FrontContactShape = 'line';
FrontMetalShape = 'H-pattern';
FrontContactNumber = 106; % 106 since Quokka3 version 1.2.1 (was 105)
FrontFingerWidth = 60;
FrontFingerShadingFraction = 0.8;
FrontContactWidth = 60;
FrontContact.OhmicResistivity = 2.7e-3; 

RearContactShape = 'line';
RearMetalShape = 'full';
RearContact.OhmicResistivity = 3e-3;
RearContactNumber = 196; % 196 since Quokka3 version 1.2.1 (was 195)
RearContactWidth = 60; % 60 um is close to the original contact fraction, and equal to the front contact width, resulting in much lower mesh size

% busbar settings
BusbarNumber = 5;
FrontBusbarWidth = 800; 
RearBusbarWidth = 1100; % width of rear Ag pads, half of actual 2.2mm thickness, as the striped pads only cover ~50% of the cell length
FrontBusbarContactEnable = 0; % results in the front contact lines (i.e. laser contact opening) also being present underneath the busbar
RearBusbarContactEnable = 0; % results in the line contacts also being present underneath the fingers
FrontMetalRsheet = 0.003;
RearMetalRsheet = 0.0175;

FrontMetalPolarity = 'n-type';
RearMetalPolarity = 'p-type';

Solver.SolutionType = 'light JV-curve';
Solver.JVCurve.VtermStepSize = 'standard';
Solver.Electrical.MetalModelType = 'finite-differences';
Solver.Electrical.SkinJ0nieff.Type = 'user-T';
Solver.Electrical.SkinJ0nieff.T = 298.15;

Optical.GenerationModelType = 'Text-Z';
Optical.FrontIllumination.Enable = 1;
Optical.FrontIllumination.Spectrum.Type = 'AM1.5g';
Optical.FrontIllumination.Scale = 1;
Optical.RearIllumination.Enable = 0;
Optical.TextZ.FrontText.Type = 'Text';
Optical.TextZ.FrontText.Text.Type = 'file';
Optical.TextZ.FrontText.Text.File = 'Trina_PERC_Text.csv';
Optical.TextZ.FrontText.FacetAngle = 54;
Optical.TextZ.FrontZ.Type = 'local'; % calculates Z locally from internal optical properties of the skins
Optical.ScaleGeneration = 1;

Thermal.T = 298.15;

Bulk.BackgroundDoping.SettingType = 'dopingtype-resistivity';
Bulk.BackgroundDoping.DopingType = 'p-type';
Bulk.BackgroundDoping.Resistivity = 1.5;
Bulk.Electrical.Recombination.Type = 'intrinsic plus SRH';
Bulk.Electrical.Recombination.SRH(1).Type = 'tau-Et';
Bulk.Electrical.Recombination.SRH(1).taun = 150;
Bulk.Electrical.Recombination.SRH(1).taup = 750;
Bulk.Electrical.Recombination.SRH(1).Et_Ei = 0;


FullFrontSkin.ElectricalModelType = 'lumped';
FullFrontSkin.Lumped.Electrical.RsheetEnable = 1;
FullFrontSkin.Lumped.Electrical.Rsheet = 148.8;
FullFrontSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
FullFrontSkin.Lumped.Electrical.NonContactedRecombination.J0 = 30.7e-15;
FullFrontSkin.Lumped.Electrical.SouthEdgeJ02 = 19e-9;
FullFrontSkin.Lumped.Electrical.NorthEdgeJ02 = 19e-9;
FullFrontSkin.Lumped.Electrical.EastEdgeJ02 = 19e-9;
FullFrontSkin.Lumped.Electrical.WestEdgeJ02 = 19e-9;
FullFrontSkin.OpticalModelType = 'lumped';
FullFrontSkin.Lumped.Optical.Internal.Rint = 0.92;
FullFrontSkin.Lumped.Optical.Internal.Diffuse = 1;

LocalFrontSkin.Enable = 1;
LocalFrontSkin.Width = 300;
LocalFrontSkin.ElectricalModelType = 'lumped';
LocalFrontSkin.Geometry.DepthType = 'user';
LocalFrontSkin.Geometry.DepthUser = 0.66;
LocalFrontSkin.Lumped.Electrical.RsheetEnable = 1;
LocalFrontSkin.Lumped.Electrical.Rsheet = 58.5;
LocalFrontSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
LocalFrontSkin.Lumped.Electrical.ContactedRecombination.J0 = 500e-15;
LocalFrontSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
LocalFrontSkin.Lumped.Electrical.NonContactedRecombination.J0 = 120e-15;
LocalFrontSkin.Lumped.Electrical.EtaColl = 0.882; % depth and collection efficiency from detailed modeling @400nm
LocalFrontSkin.OpticalModelType = 'lumped';
LocalFrontSkin.Lumped.Optical.Internal.Rint = 0.9;
LocalFrontSkin.Lumped.Optical.Internal.Diffuse = 1;

LocalFrontContactSkin.Enable = 1;
LocalFrontContactSkin.ElectricalModelType = 'lumped';
LocalFrontContactSkin.Lumped.Electrical.RsheetEnable = 1;
LocalFrontContactSkin.Lumped.Electrical.Rsheet = 60;
LocalFrontContactSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
LocalFrontContactSkin.Lumped.Electrical.ContactedRecombination.J0 = 500e-15;
% for lack of other data using passivated internal optical properties
LocalFrontContactSkin.OpticalModelType = 'lumped';
LocalFrontContactSkin.Lumped.Optical.Internal.Rint = 0.85;
LocalFrontContactSkin.Lumped.Optical.Internal.Diffuse = 1;

FullRearSkin.ElectricalModelType = 'lumped';
FullRearSkin.Lumped.Electrical.RsheetEnable = 0;
FullRearSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'Seff';
FullRearSkin.Lumped.Electrical.NonContactedRecombination.Seff = 10;
% internal optics from fit to raytracing results
FullRearSkin.OpticalModelType = 'lumped';
FullRearSkin.Lumped.Optical.Internal.Rint = 0.98;
FullRearSkin.Lumped.Optical.Internal.Diffuse = 1;

LocalRearContactSkin.Enable = 1;
LocalRearContactSkin.ElectricalModelType = 'lumped';
LocalRearContactSkin.Lumped.Electrical.RsheetEnable = 1;
LocalRearContactSkin.Lumped.Electrical.Rsheet = 60;
LocalRearContactSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
LocalRearContactSkin.Lumped.Electrical.ContactedRecombination.J0 = 400e-15;
% internal optics from fit to raytracing results
LocalRearContactSkin.OpticalModelType = 'lumped';
LocalRearContactSkin.Lumped.Optical.Internal.Rint = 0.89;
LocalRearContactSkin.Lumped.Optical.Internal.Diffuse = 1;


SouthEdgeSkin.Enable = 1;
SouthEdgeSkin.ElectricalModelType = 'lumped';
SouthEdgeSkin.Lumped.Electrical.RsheetEnable = 1;
SouthEdgeSkin.Lumped.Electrical.Rsheet = 1e10;
SouthEdgeSkin.Lumped.Electrical.ConductionType = 'p-type';
SouthEdgeSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'Seff';
SouthEdgeSkin.Lumped.Electrical.NonContactedRecombination.Seff = 1e6;

NorthEdgeSkin.Enable = 1;
NorthEdgeSkin.ElectricalModelType = 'lumped';
NorthEdgeSkin.Lumped.Electrical.RsheetEnable = 1;
NorthEdgeSkin.Lumped.Electrical.Rsheet = 1e10;
NorthEdgeSkin.Lumped.Electrical.ConductionType = 'p-type';
NorthEdgeSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'Seff';
NorthEdgeSkin.Lumped.Electrical.NonContactedRecombination.Seff = 1e6;

WestEdgeSkin.Enable = 1;
WestEdgeSkin.ElectricalModelType = 'lumped';
WestEdgeSkin.Lumped.Electrical.RsheetEnable = 1;
WestEdgeSkin.Lumped.Electrical.Rsheet = 1e10;
WestEdgeSkin.Lumped.Electrical.ConductionType = 'p-type';
WestEdgeSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'Seff';
WestEdgeSkin.Lumped.Electrical.NonContactedRecombination.Seff = 1e6;

EastEdgeSkin.Enable = 1;
EastEdgeSkin.ElectricalModelType = 'lumped';
EastEdgeSkin.Lumped.Electrical.RsheetEnable = 1;
EastEdgeSkin.Lumped.Electrical.Rsheet = 1e10;
EastEdgeSkin.Lumped.Electrical.ConductionType = 'p-type';
EastEdgeSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'Seff';
EastEdgeSkin.Lumped.Electrical.NonContactedRecombination.Seff = 1e6;

% this sweep example produces the data of figure 3 of the conference paper
Sweep.Enable = 0;
% Sweep.NGroups = 2;
% Sweep.GroupA(1).Parameter = 'FrontEdgeDistanceX';
% Sweep.GroupA(1).Values = [200 400 700 1000 1300 1600 1800 2000];
% Sweep.GroupA(2).Parameter = 'RearEdgeDistanceX';
% Sweep.GroupA(2).Values = [200 400 700 1000 1300 1600 1800 2000];
% Sweep.GroupA(3).Parameter = 'FrontEdgeDistanceY';
% Sweep.GroupA(3).Values = [200 400 700 1000 1300 1600 1800 2000];
% Sweep.GroupA(4).Parameter = 'RearEdgeDistanceY';
% Sweep.GroupA(4).Values = [200 400 700 1000 1300 1600 1800 2000];
% Sweep.GroupB(1).Parameter = 'FullFrontSkin.Lumped.Electrical.SouthEdgeJ02';
% Sweep.GroupB(1).Values = [0 19e-9];
% Sweep.GroupB(2).Parameter = 'FullFrontSkin.Lumped.Electrical.NorthEdgeJ02';
% Sweep.GroupB(2).Values = [0 19e-9];
% Sweep.GroupB(3).Parameter = 'FullFrontSkin.Lumped.Electrical.WestEdgeJ02';
% Sweep.GroupB(3).Values = [0 19e-9];
% Sweep.GroupB(4).Parameter = 'FullFrontSkin.Lumped.Electrical.EastEdgeJ02';
% Sweep.GroupB(4).Values = [0 19e-9];
% Sweep.GroupB(5).Parameter = 'SouthEdgeSkin.Lumped.Electrical.NonContactedRecombination.Seff';
% Sweep.GroupB(5).Values = [0 1e6];
% Sweep.GroupB(6).Parameter = 'NorthEdgeSkin.Lumped.Electrical.NonContactedRecombination.Seff';
% Sweep.GroupB(6).Values = [0 1e6];
% Sweep.GroupB(7).Parameter = 'WestEdgeSkin.Lumped.Electrical.NonContactedRecombination.Seff';
% Sweep.GroupB(7).Values = [0 1e6];
% Sweep.GroupB(8).Parameter = 'EastEdgeSkin.Lumped.Electrical.NonContactedRecombination.Seff';
% Sweep.GroupB(8).Values = [0 1e6];
